@@ -1,6 +1,7 @@
 use strict; use warnings;
 use Benchmark 'cmpthese';
 
+use JSON::Tiny ();
 use JSON::PP 'encode_json', 'decode_json';
 use Text::ZPL;
 
@@ -17,11 +18,16 @@ my $struct = +{
   },
 };
 
-my ($js, $zpl);
-cmpthese( 5_000, +{
+my $tiny = JSON::Tiny->new;
+
+my ($js, $tjs, $zpl);
+cmpthese( 2_000, +{
   encode_jsonpp => sub {
     $js = encode_json $struct
   },
+  encode_jsontiny => sub {
+    $tjs = $tiny->encode($struct)
+  },
   encode_zpl => sub {
     $zpl = encode_zpl $struct
   },
@@ -31,6 +37,9 @@ cmpthese( 2_000, +{
   decode_jsonpp => sub {
     decode_json $js
   },
+  decode_jsontiny => sub {
+    $tiny->decode($tjs)
+  },
   decode_zpl => sub {
     decode_zpl $zpl
   },
