@@ -1,5 +1,5 @@
 package Text::ZPL;
-$Text::ZPL::VERSION = '0.002002';
+$Text::ZPL::VERSION = '0.003001';
 use strict; use warnings FATAL => 'all';
 no warnings 'void';
 
@@ -18,34 +18,26 @@ our $ValidName = qr/[A-Za-z0-9\$\-_\@.&+\/]+/;
 
 
 sub decode_zpl {
-  my ($str) = @_;
-
   confess "Expected a ZPL text string but received no arguments"
-    unless defined $str;
+    unless defined $_[0];
 
-  my $root = +{};
-  my $ref  = $root;
+  my $root = my $ref = +{};
   my @descended;
 
   my ($level, $lineno) = (0,0);
 
-  LINE: for my $line (split /(?:\015?\012)|\015/, $str) {
+  LINE: for my $line (split /(?:\015?\012)|\015/, $_[0]) {
     ++$lineno;
     # Prep string in-place & skip blank/comments-only:
     next LINE unless _decode_prepare_line($line);
 
-    # Manage structure:
     _decode_handle_level($lineno, $line, $root, $ref, $level, \@descended);
 
-    # KV pair:
     if ( (my $sep_pos = index($line, '=')) > 0 ) {
       my ($key, $val) = _decode_parse_kv($lineno, $line, $level, $sep_pos);
       _decode_add_kv($lineno, $ref, $key, $val);
       next LINE
-    }
-
-    # New subsection:
-    if (my ($subsect) = $line =~ /^(?:\s+)?($ValidName)(?:\s+?#.*)?$/) {
+    } elsif (my ($subsect) = $line =~ /^(?:\s+)?($ValidName)(?:\s+?#.*)?$/) {
       _decode_add_subsection($lineno, $ref, $subsect, \@descended);
       next LINE
     }
@@ -60,7 +52,7 @@ sub decode_zpl {
 
 sub _decode_prepare_line {
   $_[0] =~ s/\s+$//;
-  length($_[0]) == 0 || $_[0] =~ /^(?:\s+)?#/ ? () : 1
+  !(length($_[0]) == 0 || $_[0] =~ /^(?:\s+)?#/)
 }
 
 sub _decode_handle_level {
@@ -90,11 +82,6 @@ sub _decode_handle_level {
   } elsif ($cur_indent < $_[4]) {
     my $wanted_idx = ( ($_[4] - $cur_indent) / 4 ) - 1 ;
     my $wanted_ref = $_[5]->[$wanted_idx];
-    unless (defined $wanted_ref) {
-      confess
-        "BUG; cannot find matching parent section"
-        ." [idx = $wanted_idx] [indent = $cur_indent]"
-    }
     $_[3] = $wanted_ref;
     $_[4] = $cur_indent;
     @{ $_[5] } = @{ $_[5] }[ ($wanted_idx + 1) .. $#{ $_[5] } ];
@@ -104,7 +91,7 @@ sub _decode_handle_level {
 sub _decode_add_subsection {
   # ($lineno, $ref, $subsect, \@descended)
   if (exists $_[1]->{ $_[2] }) {
-    confess "Invalid ZPL (line $_[0]); existing property with this name"
+    confess "Invalid ZPL (line $_[0]); existing property '$_[2]'"
   }
   unshift @{ $_[3] }, $_[1];
   $_[1] = $_[1]->{ $_[2] } = +{};
@@ -126,6 +113,7 @@ sub _decode_parse_kv {
 
   my $tmpval = substr $_[1], $_[3] + 1;
   $tmpval =~ s/^\s+//;
+
   my $realval;
   my $maybe_q = substr $tmpval, 0, 1;
   if ( ($maybe_q eq q{'} || $maybe_q eq q{"}) 
@@ -141,8 +129,7 @@ sub _decode_parse_kv {
       '';
   }
 
-  $tmpval =~ s/#.*$//;
-  $tmpval =~ s/\s+//;
+  $tmpval =~ s/(?:\s+)?(?:#.*)?$//;
   if (length $tmpval) {
     confess "Invalid ZPL (line $_[0]); garbage at end-of-line: '$tmpval'"
   }
@@ -156,13 +143,13 @@ sub _decode_add_kv {
   # Add a value to property; create lists as-needed
 
   if (exists $_[1]->{ $_[2] }) {
-    if (ref $_[1]->{ $_[2] } eq 'HASH') {
-      confess
-        "Invalid ZPL (line $_[0]); existing subsection with this name"
+    if (! ref $_[1]->{ $_[2] }) {
+      $_[1]->{ $_[2] } = [ $_[1]->{ $_[2] }, $_[3] ]
     } elsif (ref $_[1]->{ $_[2] } eq 'ARRAY') {
       push @{ $_[1]->{ $_[2] } }, $_[3]
-    } else {
-      $_[1]->{ $_[2] } = [ $_[1]->{ $_[2] }, $_[3] ]
+    } elsif (ref $_[1]->{ $_[2] } eq 'HASH') {
+      confess
+        "Invalid ZPL (line $_[0]); existing subsection with this name"
     }
     return
   }
@@ -251,9 +238,13 @@ Text::ZPL - Encode and decode ZeroMQ Property Language
 
   # Decode ZPL to a HASH:
   my $data = decode_zpl( $zpl_text );
+
   # Encode a HASH to ZPL text:
   my $zpl = encode_zpl( $data );
 
+  # From a shell; examine the Perl representation of a ZPL document:
+  sh$ zpl_to_pl my_config.zpl
+
 =head1 DESCRIPTION
 
 An implementation of the C<ZeroMQ Property Language>, a simple ASCII
@@ -343,7 +334,9 @@ Encoding skips empty lists (C<ARRAY> references).
 
 =head1 SEE ALSO
 
-L<Text::ZPL::Stream>
+The L<Text::ZPL::Stream> module for processing ZPL piecemeal.
+
+The bundled L<zpl_to_pl> script for examining parsed ZPL.
 
 =head1 AUTHOR
 
