@@ -1,12 +1,11 @@
 package Text::ZPL::Stream;
-$Text::ZPL::Stream::VERSION = '0.002002';
+$Text::ZPL::Stream::VERSION = '0.003001';
 use strict; use warnings FATAL => 'all';
 use Carp;
 
 use Text::ZPL ();
 
 
-
 sub BUF_MAX         () { 0 }
 sub BUF             () { 1 }
 sub MAYBE_EXTRA_EOL () { 2 }
@@ -15,6 +14,7 @@ sub CURRENT         () { 4 }
 sub LEVEL           () { 5 }
 sub TREE            () { 6 }
 
+
 sub new {
   #  max_buffer_size =>
   #  string =>
@@ -33,8 +33,7 @@ sub new {
 
 sub max_buffer_size {
   defined $_[0]->[BUF_MAX] ?
-    $_[0]->[BUF_MAX]
-    : ($_[0]->[BUF_MAX] = 0)
+    $_[0]->[BUF_MAX] : ( $_[0]->[BUF_MAX] = 0 )
 }
 
 
